aboutsummaryrefslogtreecommitdiff
path: root/sway/input/cursor.c
diff options
context:
space:
mode:
authorBrian Ashworth <RedSoxFan@users.noreply.github.com>2018-07-25 21:30:56 -0400
committerGitHub <noreply@github.com>2018-07-25 21:30:56 -0400
commit75ebeb4a167ca218af37fa9041223a6450dc20f4 (patch)
tree47456198945ceea9f105dc9122ebbdf2013872ce /sway/input/cursor.c
parentc8dc9b3b3094c9b2778309855114b9495518c2d4 (diff)
parent868dcde14ef2116fcbd5c2c66badf2bcc514bba3 (diff)
Merge pull request #2356 from RyanDwyer/fullscreen-containers
Allow containers to be fullscreen
Diffstat (limited to 'sway/input/cursor.c')
-rw-r--r--sway/input/cursor.c14
1 files changed, 4 insertions, 10 deletions
diff --git a/sway/input/cursor.c b/sway/input/cursor.c
index 02bd2239..cc0dbe99 100644
--- a/sway/input/cursor.c
+++ b/sway/input/cursor.c
@@ -99,14 +99,8 @@ static struct sway_container *container_at_coords(
return ws;
}
if (ws->sway_workspace->fullscreen) {
- struct wlr_surface *wlr_surface = ws->sway_workspace->fullscreen->surface;
- if (wlr_surface_point_accepts_input(wlr_surface, ox, oy)) {
- *sx = ox;
- *sy = oy;
- *surface = wlr_surface;
- return ws->sway_workspace->fullscreen->swayc;
- }
- return NULL;
+ return container_at(ws->sway_workspace->fullscreen, lx, ly,
+ surface, sx, sy);
}
if ((*surface = layer_surface_at(output,
&output->layers[ZWLR_LAYER_SHELL_V1_LAYER_TOP],
@@ -438,8 +432,8 @@ static void dispatch_cursor_button_floating(struct sway_cursor *cursor,
struct sway_container *cont) {
struct sway_seat *seat = cursor->seat;
- // Deny moving or resizing a fullscreen view
- if (cont->type == C_VIEW && cont->sway_view->is_fullscreen) {
+ // Deny moving or resizing a fullscreen container
+ if (container_is_fullscreen_or_child(cont)) {
seat_pointer_notify_button(seat, time_msec, button, state);
return;
}